<?php
require_once get_parent_theme_file_path( '/includes/woocommerce/wc-functions.php' );
require_once get_parent_theme_file_path( '/includes/woocommerce/wc-functions-variations.php' );

add_filter( 'ciyashop_supported_shortcodes', 'ciyashop_add_woocommerce_supported_shortcodes' );
function ciyashop_add_woocommerce_supported_shortcodes( $shortcodes ) {

	if ( class_exists( 'WooCommerce' ) ) {
		$shortcodes = array_merge(
			$shortcodes,
			array(
				'pgscore_categorybox',
				'pgscore_single_product_slider',
				'pgscore_product_deal',
				'pgscore_product_deals',
				'pgscore_multi_tab_products_listing',
				'pgscore_products_listing',
				'pgscore_product_showcase',
			)
		);
	}

	return $shortcodes;
}

/********************************************************************
 *
 * Ajax
 *
 ********************************************************************/
function ciyashop_quick_view() {
	if ( isset( $_GET['id'] ) ) {
		$id = (int) $_GET['id'];
	}
	if ( ! $id ) {
		return;
	}

	global $post, $ciyashop_options, $sitepress;

	$lang = isset( $_GET['lang'] ) ? $_GET['lang'] : '';

	if ( defined( 'ICL_LANGUAGE_CODE' ) && $lang && isset( $sitepress ) ) {
		$sitepress->switch_lang( $lang, true );
	}

	$args = array(
		'post__in'  => array( $id ),
		'post_type' => 'product',
	);

	$quick_posts = get_posts( $args );

	$quick_view_variable = $ciyashop_options['quick_view'];

	foreach ( $quick_posts as $post ) :

		setup_postdata( $post, $sitepress );
		remove_action( 'woocommerce_before_single_product', 'wc_print_notices', 10 );

		if ( ! $ciyashop_options['quick_view_product_name'] ) {
			remove_action( 'woocommerce_single_product_summary', 'woocommerce_template_single_title', 5 );
		}
		if ( $ciyashop_options['quick_view_product_name'] && $ciyashop_options['quick_view_product_link'] ) {
			remove_action( 'woocommerce_single_product_summary', 'woocommerce_template_single_title', 5 );
			add_action( 'woocommerce_single_product_summary', 'ciyashop_woocommerce_template_single_title', 5 );
		}
		if ( ! $ciyashop_options['quick_view_product_categories'] ) {
			remove_action( 'woocommerce_single_product_summary', 'woocommerce_template_single_meta', 40 );
			remove_action( 'woocommerce_single_product_summary', 'woocommerce_template_single_meta', 29 );
		}
		if ( ! $ciyashop_options['quick_view_product_price'] ) {
			remove_action( 'woocommerce_single_product_summary', 'woocommerce_template_single_price', 10 );
		}
		if ( ! $ciyashop_options['quick_view_product_star_rating'] ) {
			remove_action( 'woocommerce_single_product_summary', 'woocommerce_template_single_rating', 10 );
		}
		if ( ! $ciyashop_options['quick_view_product_short_description'] ) {
			remove_action( 'woocommerce_single_product_summary', 'woocommerce_template_single_excerpt', 20 );
		}
		if ( ! $ciyashop_options['quick_view_product_add_to_cart'] ) {
			remove_action( 'woocommerce_single_product_summary', 'woocommerce_template_single_add_to_cart', 30 );
		}
		if ( ! $ciyashop_options['quick_view_product_share_icon'] ) {
			remove_action( 'woocommerce_single_product_summary', 'woocommerce_template_single_sharing', 50 );
		}
		// Disable add to cart button for catalog mode
		if ( $ciyashop_options['woocommerce_catalog_mode'] ) {
			remove_action( 'woocommerce_single_product_summary', 'woocommerce_template_single_add_to_cart', 30 );
		} elseif ( ! $quick_view_variable ) {
			// If no needs to show variations
			remove_action( 'woocommerce_single_product_summary', 'woocommerce_template_single_add_to_cart', 30 );
			add_action( 'woocommerce_single_product_summary', 'woocommerce_template_loop_add_to_cart', 30 );
		}

		remove_action( 'woocommerce_single_product_summary', 'ciyashop_product_sale_countdown', 41 );
		remove_action( 'woocommerce_after_shop_loop_item', 'ciyashop_product_sale_countdown', 25 );

		get_template_part( 'woocommerce/content', 'quick-view' );
	endforeach;

	wp_reset_postdata();

	die();
}

add_action( 'wp_ajax_ciyashop_quick_view', 'ciyashop_quick_view' );
add_action( 'wp_ajax_nopriv_ciyashop_quick_view', 'ciyashop_quick_view' );

/**********************************************************
 *
 * Product Share
 *
 **********************************************************/
function ciyashop_woocommerce_share() {
	global $ciyashop_options;

	if ( ! $ciyashop_options['product-share-buttons'] ) {
		return;
	}
	?>
	<div class="pgs-social-share-wrapper share-wrapper social-profiles">
		<span class="share-label"><?php esc_html_e( 'Share :', 'ciyashop' ); ?></span>
		<?php
		ciyashop_social_share(
			array(
				'class' => 'share-links',
			)
		);
		?>
	</div>
	<?php
}
add_action( 'woocommerce_share', 'ciyashop_woocommerce_share', 10, 0 );

/**********************************************************
 *
 * Registration Info
 *
 **********************************************************/

/* Set the registration info text on woocommerce register page */
add_action( 'woocommerce_register_form_start', 'ciyashop_register_form_start' );
function ciyashop_register_form_start() {
	global $ciyashop_options;

	if ( $ciyashop_options['enable_registration_text'] && '' != $ciyashop_options['registration_text'] ) {
		?>
		<div class="woo-registration-info">
		<?php echo do_shortcode( $ciyashop_options['registration_text'] ); ?>
		</div>
		<?php
	}
}
